@@ -1,3 +1,16 @@
+from os.path import dirname, join
+
+
+def get_ver():
+    with open(join(dirname(__file__), "VERSION")) as version_file:
+        return version_file.read().strip()
+
+
+__version__ = get_ver()
+__creator__ = "Jason Mars"
+__url__ = "https://jaseci.org"
+
+
 def load_standard():
     import jaseci.actions.standard.net  # noqa
     import jaseci.actions.standard.rand  # noqa
