@@ -1,37 +1,37 @@
 """
 Graph api functions as a mixin
 """
-from jaseci.api.interface import interface
-from jaseci.utils.id_list import id_list
-from jaseci.graph.graph import graph
-from jaseci.graph.node import node
-from jaseci.actor.sentinel import sentinel
+from jaseci.api.interface import Interface
+from jaseci.utils.id_list import IdList
+from jaseci.graph.graph import Graph
+from jaseci.graph.node import Node
+from jaseci.actor.sentinel import Sentinel
 import uuid
 
 
-class graph_api:
+class GraphApi:
     """
     Graph APIs
     """
 
     def __init__(self):
         self.active_gph_id = None
-        self.graph_ids = id_list(self)
+        self.graph_ids = IdList(self)
 
-    @interface.private_api()
+    @Interface.private_api()
     def graph_create(self, set_active: bool = True):
         """
         Create a graph instance and return root node graph object
         """
-        gph = graph(m_id=self._m_id, h=self._h)
+        gph = Graph(m_id=self._m_id, h=self._h)
         self.graph_ids.add_obj(gph)
         if set_active:
             self.graph_active_set(gph)
         return gph.serialize()
 
-    @interface.private_api()
+    @Interface.private_api()
     def graph_get(
-        self, gph: graph = None, mode: str = "default", detailed: bool = False
+        self, gph: Graph = None, mode: str = "default", detailed: bool = False
     ):
         """
         Return the content of the graph with mode
@@ -47,7 +47,7 @@ class graph_api:
                 items.append(i.serialize(detailed=detailed))
             return items
 
-    @interface.private_api()
+    @Interface.private_api()
     def graph_list(self, detailed: bool = False):
         """
         Provide complete list of all graph objects (list of root node objects)
@@ -57,8 +57,8 @@ class graph_api:
             gphs.append(i.serialize(detailed=detailed))
         return gphs
 
-    @interface.private_api(cli_args=["gph"])
-    def graph_active_set(self, gph: graph):
+    @Interface.private_api(cli_args=["gph"])
+    def graph_active_set(self, gph: Graph):
         """
         Sets the default graph master should use
         """
@@ -66,7 +66,7 @@ class graph_api:
         self.alias_register("active:graph", gph.jid)
         return [f"Graph {gph.id} set as default"]
 
-    @interface.private_api()
+    @Interface.private_api()
     def graph_active_unset(self):
         """
         Unsets the default sentinel master should use
@@ -75,7 +75,7 @@ class graph_api:
         self.alias_delete("active:graph")
         return ["Default graph unset"]
 
-    @interface.private_api()
+    @Interface.private_api()
     def graph_active_get(self, detailed: bool = False):
         """
         Returns the default graph master is using
@@ -86,8 +86,8 @@ class graph_api:
         else:
             return {"success": False, "response": "No default graph is selected!"}
 
-    @interface.private_api(cli_args=["gph"])
-    def graph_delete(self, gph: graph):
+    @Interface.private_api(cli_args=["gph"])
+    def graph_delete(self, gph: Graph):
         """
         Permanently delete graph with given id
         """
@@ -96,8 +96,8 @@ class graph_api:
         self.graph_ids.destroy_obj(gph)
         return [f"Graph {gph.id} successfully deleted"]
 
-    @interface.private_api(cli_args=["nd"])
-    def graph_node_get(self, nd: node, keys: list = []):
+    @Interface.private_api(cli_args=["nd"])
+    def graph_node_get(self, nd: Node, keys: list = []):
         """
         Returns value a given node
         """
@@ -108,8 +108,8 @@ class graph_api:
                 ret[i] = nd_ctx[i]
         return ret
 
-    @interface.private_api(cli_args=["nd"])
-    def graph_node_set(self, nd: node, ctx: dict, snt: sentinel = None):
+    @Interface.private_api(cli_args=["nd"])
+    def graph_node_set(self, nd: Node, ctx: dict, snt: Sentinel = None):
         """
         Assigns values to member variables of a given node using ctx object
         """
@@ -118,8 +118,8 @@ class graph_api:
         temp_ref_nd.destroy()
         return nd.serialize()
 
-    @interface.cli_api(cli_args=["file"])
-    def graph_walk(self, nd: node = None):
+    @Interface.cli_api(cli_args=["file"])
+    def graph_walk(self, nd: Node = None):
         cmd = ""
         while cmd not in ["quit", "q", "exit"]:
             print(
