@@ -5,12 +5,12 @@ import uuid
 from inspect import signature, getdoc
 from jaseci.utils.utils import logger
 from jaseci.utils.utils import is_jsonable
-from jaseci.element.element import element
-from jaseci.actor.walker import walker
+from jaseci.element.element import Element
+from jaseci.actor.walker import Walker
 import json
 
 
-class interface:
+class Interface:
     """
     General master interface engine
     """
@@ -51,8 +51,8 @@ class interface:
 
     def public_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
-            return interface.assimilate_api(
-                interface._public_api,
+            return Interface.assimilate_api(
+                Interface._public_api,
                 func,
                 cmd_group,
                 cli_args,
@@ -64,8 +64,8 @@ class interface:
 
     def private_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
-            return interface.assimilate_api(
-                interface._private_api,
+            return Interface.assimilate_api(
+                Interface._private_api,
                 func,
                 cmd_group,
                 cli_args,
@@ -77,8 +77,8 @@ class interface:
 
     def admin_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
-            return interface.assimilate_api(
-                interface._admin_api,
+            return Interface.assimilate_api(
+                Interface._admin_api,
                 func,
                 cmd_group,
                 cli_args,
@@ -90,16 +90,16 @@ class interface:
 
     def cli_api(cmd_group=None, cli_args=None):
         def decorator_func(func):
-            return interface.assimilate_api(
-                interface._cli_api, func, cmd_group, cli_args
+            return Interface.assimilate_api(
+                Interface._cli_api, func, cmd_group, cli_args
             )
 
         return decorator_func
 
     def all_apis(self, with_cli_only=False):
-        ret = interface._public_api + interface._private_api + interface._admin_api
+        ret = Interface._public_api + Interface._private_api + Interface._admin_api
         if with_cli_only:
-            return ret + interface._cli_api
+            return ret + Interface._cli_api
         return ret
 
     assimilate_api = staticmethod(assimilate_api)
@@ -177,7 +177,7 @@ class interface:
                     val = json.loads(val)
             if str(val) in _caller.alias_map.keys():
                 val = _caller.alias_map[val]
-            if issubclass(p_type, element):
+            if issubclass(p_type, Element):
                 if val is None:
                     break
                 val = _caller._h.get_obj(_caller._m_id, uuid.UUID(val))
@@ -227,7 +227,7 @@ class interface:
                     val = {}
                 else:
                     val = json.loads(val)
-            if issubclass(p_type, element):
+            if issubclass(p_type, Element):
                 if val is None:
                     return self.interface_error(
                         f"No {p_type} value for {p_name} provided!"
@@ -259,7 +259,7 @@ class interface:
 
     # future constraints other than `async` should be add here
     def sync_constraints(self, obj, params):
-        if isinstance(obj, walker):
+        if isinstance(obj, Walker):
             obj._async = params.get("is_async", False)
 
         return obj
