@@ -8,20 +8,21 @@ Naming conventions
 * 'store' - refers to persistent store for hooks from engine, (dont use db)
 """
 
-import uuid
-from datetime import datetime
 import copy
 import json
-from jaseci.utils.id_list import id_list
-from jaseci.utils.mem_hook import mem_hook
-from jaseci.utils.utils import logger, log_var_out
+import uuid
+from datetime import datetime
+
+from jaseci.element.obj_mixins import Hookable
+from jaseci.hook import MemoryHook
+from jaseci.utils.id_list import IdList
 from jaseci.utils.json_handler import JaseciJsonEncoder, json_str_to_jsci_dict
-from jaseci.element.obj_mixins import hookable
+from jaseci.utils.utils import log_var_out, logger, camel_to_snake
 
 __version__ = "1.0.0"
 
 
-class element(hookable):
+class Element(Hookable):
     """
     Base class for Jaseci for standard info shared across all objects types in
     Jaseci. This class also includes a method for dumping the non-general items
@@ -59,10 +60,10 @@ class element(hookable):
         self.jid = uuid.uuid4().urn
         self.j_parent = parent_id.urn if parent_id else None  # member of
         self.j_timestamp = datetime.utcnow().isoformat()
-        self.j_type = type(self).__name__
+        self.j_type = camel_to_snake(type(self).__name__)
         if self.is_master():
             m_id = self.jid
-        hookable.__init__(self, h, m_id, *args, **kwargs)
+        Hookable.__init__(self, h, m_id, *args, **kwargs)
         if auto_save:
             self.save()
 
@@ -117,8 +118,8 @@ class element(hookable):
         dup = type(self)(m_id=self._m_id, h=self._h, persist=persist_dup)
         id_save = dup.id
         for i in dup.__dict__.keys():
-            if type(dup.__dict__[i]) == id_list:
-                setattr(dup, i, id_list(parent_obj=dup, in_list=self.__dict__[i]))
+            if type(dup.__dict__[i]) == IdList:
+                setattr(dup, i, IdList(parent_obj=dup, in_list=self.__dict__[i]))
             else:
                 setattr(dup, i, self.__dict__[i])
         dup.id = id_save
@@ -146,7 +147,7 @@ class element(hookable):
         saving and loading item.
         """
         obj_fields = []
-        element_fields = dir(element(m_id=self._m_id, h=mem_hook()))
+        element_fields = dir(Element(m_id=self._m_id, h=MemoryHook()))
         for i in vars(self).keys():
             if not i.startswith("_") and i not in element_fields:
                 obj_fields.append(i)
@@ -179,7 +180,7 @@ class element(hookable):
                     if "_private" in jdict[i].keys():
                         for j in jdict[i]["_private"]:
                             del jdict[i][j]
-                if deep > 0 and isinstance(jdict[i], id_list):
+                if deep > 0 and isinstance(jdict[i], IdList):
                     for j in range(len(jdict[i])):
                         jdict[i][j] = copy.copy(
                             self._h.get_obj(
@@ -217,7 +218,7 @@ class element(hookable):
             objs = []
         objs.append(self)
         for i in self.__dict__.keys():
-            if str(i).endswith("_ids") and isinstance(self.__dict__[i], id_list):
+            if str(i).endswith("_ids") and isinstance(self.__dict__[i], IdList):
                 for j in self.__dict__[i].obj_list():
                     if j not in objs:
                         j.get_deep_obj_list(objs=objs)
