@@ -4,13 +4,13 @@ Edge class for Jaseci
 Each edge has an id, name, timestamp, the from node at the element of the edge
 and the to node it is pointing to.
 """
-from jaseci.element.element import element
-from jaseci.element.obj_mixins import anchored
+from jaseci.element.element import Element
+from jaseci.element.obj_mixins import Anchored
 from jaseci.utils.utils import logger
 import uuid
 
 
-class edge(element, anchored):
+class Edge(Element, Anchored):
     """Edge class for Jaseci"""
 
     def __init__(self, from_node=None, to_node=None, *args, **kwargs):
@@ -18,8 +18,8 @@ class edge(element, anchored):
         self.to_node_id = None
         self.bidirected: bool = False
         self.context = {}
-        anchored.__init__(self)
-        element.__init__(self, *args, **kwargs)
+        Anchored.__init__(self)
+        Element.__init__(self, *args, **kwargs)
         if from_node:
             self.set_from_node(from_node)
         if to_node:
@@ -149,7 +149,7 @@ class edge(element, anchored):
             base.edge_ids.remove_obj(self)
         if target and self.jid in target.edge_ids:
             target.edge_ids.remove_obj(self)
-        element.destroy(self)
+        Element.destroy(self)
 
     def dot_str(self, node_map=None, edge_map=None, detailed=False):
         """
