@@ -1,7 +1,7 @@
-from jaseci.utils.test_core import core_test
+from jaseci.utils.test_core import CoreTest
 
 
-class interpreter_test(core_test):
+class InterpreterTest(CoreTest):
     """Unit tests for Jac Interpreter / Language features"""
 
     fixture_src = __file__
@@ -22,12 +22,14 @@ class interpreter_test(core_test):
             ["sentinel_register", {"code": self.load_jac("lang_features.jac")}],
         )
         ret = self.call(self.mast, ["walker_run", {"name": "deref_adaptive"}])
-        # this unit test is inconsistent.
-        # It throws failed sometimes but success after some retrigger
-        # adding this print for now just to monitor once it throws error again
-        # print(ret)
-        self.assertTrue(ret["report"][0].startswith("junk and stuff"))
-        self.assertEqual(ret["report"][1], {"name": "node0"})
+        self.assertTrue(
+            ret["report"][0].startswith("junk and stuff")
+            or ret["report"][1].startswith("junk and stuff")
+        )
+        self.assertTrue(
+            ret["report"][1] == {"name": "node0"}
+            or ret["report"][0] == {"name": "node0"}
+        )
 
     def test_deref_of_element_fails(self):
         ret = self.call(
