@@ -1,23 +1,24 @@
-from antlr4 import InputStream, CommonTokenStream
+import os
+from unittest import TestCase
+
+from antlr4 import CommonTokenStream, InputStream
+
+import jaseci.actions.live_actions as lact
+import jaseci.tests.jac_test_code as jtc
+from jaseci.actor.sentinel import Sentinel
+from jaseci.graph.graph import Graph
 from jaseci.jac.jac_parse.jacLexer import jacLexer
 from jaseci.jac.jac_parse.jacParser import jacParser
-from jaseci.svcs.meta_svc import meta_svc
-from jaseci.actor.sentinel import sentinel
-from jaseci.graph.graph import graph
-import jaseci.actions.live_actions as lact
-import os
-
+from jaseci.svc import MetaService
 from jaseci.utils.utils import TestCaseHelper
-from unittest import TestCase
-import jaseci.tests.jac_test_code as jtc
 
 
-class jac_tests(TestCaseHelper, TestCase):
+class JacTests(TestCaseHelper, TestCase):
     """Unit tests for Jac language"""
 
     def setUp(self):
         super().setUp()
-        self.meta = meta_svc()
+        self.meta = MetaService()
 
     def tearDown(self):
         super().tearDown()
@@ -33,16 +34,16 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_jac_code(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         self.assertIsNotNone(sent.walker_ids.get_obj_by_name("get_gen_day"))
         self.assertIsNotNone(sent.arch_ids.get_obj_by_name("week", kind="node"))
 
     def test_sentinel_loading_jac_code_multiple_times(self):
         """Test registering resets correctly for multiple attempts"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog0)
         num_walkers = len(sent.walker_ids)
         num_arch = len(sent.arch_ids)
@@ -55,8 +56,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_register_dep_on_static_errors(self):
         """Test Jac registering is dependant on correct static/dynamic code"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         correct = "node b { has anchor a; }"
         wrong1 = "adfdsf"
         sent.register_code(correct)
@@ -72,8 +73,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_arhitype(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         self.assertGreater(
             len(sent.arch_ids.get_obj_by_name("month", kind="node").code_ir), 5
@@ -81,8 +82,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_running_basic_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
@@ -98,8 +99,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_setp_running_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
@@ -122,8 +123,8 @@ class jac_tests(TestCaseHelper, TestCase):
         """
         Test that  no loss or gain of data on second trak on second trek
         """
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
@@ -145,8 +146,8 @@ class jac_tests(TestCaseHelper, TestCase):
         scalably (node contexts dont get deleted when arch_ids deleted)
         """
         lact.load_local_actions(os.path.dirname(__file__) + "/infer.py")
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
         test_walker = sent.walker_ids.get_obj_by_name("get_gen_day")
@@ -163,8 +164,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sent_loads_complex_walker_and_arch(self):
         """Test loading attributes of arch and walkers"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("testnode", kind="node").run()
         test_walker = sent.walker_ids.get_obj_by_name("testwalk")
@@ -178,8 +179,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_work(self):
         """Test that multiple edges between the same two nodes are allowed"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -193,8 +194,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -204,8 +205,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_specific(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2b)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -215,8 +216,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_labeled(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2c)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -226,8 +227,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_filtered(self):
         """Test that multiple edges deleted correctly if delete filtered"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey3)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -237,8 +238,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_generic_can_be_used_to_specify_generic_edges(self):
         """Test that generic edge tag works"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey4)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -248,8 +249,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_simultaneously(self):
         """Test disconnecting mutilpe nodes"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey5)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -259,8 +260,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_connect_multi_nodes_simultaneously(self):
         """Test connecting mutilpe nodes"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey6)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -270,8 +271,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_advanced(self):
         """Test disconnecting mutilpe nodes advanced"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey7)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -281,8 +282,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_accessing_edges_basic(self):
         """Test accessing Edges"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edge_access)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -297,8 +298,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_has_assign(self):
         """Test assignment on definition"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.has_assign)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -315,8 +316,8 @@ class jac_tests(TestCaseHelper, TestCase):
     def test_global_get_set(self):
         """Test assignment on definition"""
         mast = self.meta.super_master()
-        gph = graph(m_id=mast.jid, h=mast._h)
-        sent = sentinel(m_id=mast.jid, h=gph._h)
+        gph = Graph(m_id=mast.jid, h=mast._h)
+        sent = Sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.set_get_global)
         test_walker = sent.walker_ids.get_obj_by_name("setter")
         test_walker.prime(gph)
@@ -329,8 +330,8 @@ class jac_tests(TestCaseHelper, TestCase):
     def test_global_set_requires_admin(self):
         """Test assignment on definition"""
         mast = self.meta.master()
-        gph = graph(m_id=mast.jid, h=mast._h)
-        sent = sentinel(m_id=mast.jid, h=gph._h)
+        gph = Graph(m_id=mast.jid, h=mast._h)
+        sent = Sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.set_get_global)
         test_walker = sent.walker_ids.get_obj_by_name("setter")
         test_walker.prime(gph)
@@ -343,15 +344,15 @@ class jac_tests(TestCaseHelper, TestCase):
     def test_sentinel_version_label(self):
         """Test sentinel version labeling"""
         mast = self.meta.master()
-        gph = graph(m_id=mast.jid, h=mast._h)
-        sent = sentinel(m_id=mast.jid, h=gph._h)
+        gph = Graph(m_id=mast.jid, h=mast._h)
+        sent = Sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.version_label)
         self.assertEqual(sent.version, "alpha-1.0")
 
     def test_visibility_builtins(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.visibility_builtins)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -363,8 +364,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_spawn_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.spawn_ctx_edge_node)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -376,8 +377,8 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_filter_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.filter_ctx_edge_node)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -386,8 +387,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.report[1]), 0)
 
     def test_null_handling(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.null_handleing)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -398,8 +399,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[3], False)
 
     def test_bool_type_convert(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.bool_type_convert)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -408,8 +409,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(True, test_walker.report[1]["name"])
 
     def test_typecasts(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.typecasts)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -422,8 +423,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[5], "Types comes back correct")
 
     def test_typecast_error(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.typecasts_error)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -435,8 +436,8 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_filter_on_context(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.filter_on_context)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -446,8 +447,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn("name", test_walker.report[0][2].keys())
 
     def test_string_manipulation(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.string_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -485,8 +486,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[29], True)
 
     def test_list_manipulation(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.list_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -505,8 +506,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[10], [])
 
     def test_list_reversed(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.list_reversed)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -516,8 +517,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[1], [4, 2, 7])
 
     def test_dict_manipulation(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.dict_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -533,8 +534,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[7], {})
 
     def test_string_join(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.string_join)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -543,8 +544,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0], "test_me_now")
 
     def test_sub_list(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.sub_list)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -555,8 +556,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0][2], 7)
 
     def test_destroy_and_misc(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.destroy_and_misc)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -580,8 +581,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[9], True)
 
     def test_arbitrary_assign_on_element(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.arbitrary_assign_on_element)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -592,8 +593,8 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_try_else_stmts(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.try_else_stmts)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -617,8 +618,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[3], 2)
 
     def test_node_edge_same_name(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.node_edge_same_name)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -630,8 +631,8 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_testcases(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.testcases)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 4)
@@ -639,8 +640,8 @@ class jac_tests(TestCaseHelper, TestCase):
             self.assertEqual(i["passed"], True)
 
     def test_testcase_asserts(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.testcase_asserts)
         sent.run_tests(silent=True)
         self.assertEqual(len(sent.testcases), 3)
@@ -649,8 +650,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(sent.testcases[2]["passed"], False)
 
     def test_report_not_to_jacset(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.report_not_to_jacset)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -660,8 +661,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn("j_type", rep[0][0].keys())
 
     def test_walker_spawn_unwrap_check(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.walker_spawn_unwrap_check)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -670,8 +671,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertTrue(rep[0].startswith("urn:uuid"))
 
     def test_std_get_report(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.std_get_report)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -680,8 +681,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 6, 7, [3, 5, 6, 7], 8])
 
     def test_func_with_array_index(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.func_with_array_index)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -690,8 +691,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 3])
 
     def test_rt_error_test1(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.rt_error_test1)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -701,8 +702,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn(" col ", test_walker.runtime_errors[0])
 
     def test_root_type_nodes(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.root_type_nodes)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -711,8 +712,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["root", "root"])
 
     def test_invalid_key_error(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.invalid_key_error)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -721,8 +722,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertGreater(len(errors), 0)
 
     def test_auto_cast(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.auto_cast)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -731,8 +732,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, [True, True])
 
     def test_no_error_on_dict_key_assign(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.no_error_on_dict_key_assign)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -742,8 +743,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.runtime_errors), 0)
 
     def test_report_status(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.report_status)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -753,8 +754,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report_status, 302)
 
     def test_graph_in_graph(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.graph_in_graph)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -763,8 +764,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(report), 3)
 
     def test_min_max_on_list(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.min_max_on_list)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -773,8 +774,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, [531.1, 3, 5, 1])
 
     def test_edge_bug(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edge_bug)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
@@ -783,8 +784,8 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(report[0]), 4)
 
     def test_rand_choice(self):
-        gph = graph(m_id="anon", h=self.meta.hook())
-        sent = sentinel(m_id="anon", h=gph._h)
+        gph = Graph(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.rand_choice)
         test_walker = sent.walker_ids.get_obj_by_name("init")
         test_walker.prime(gph)
